pub struct Renderer {
pub(crate) width: u32,
pub(crate) height: u32,
pub(crate) world: World,
}Fields
width: u32height: u32world: WorldImplementations
Sourceimpl Renderer
impl Renderer
pub fn width(&self) -> u32
pub fn height(&self) -> u32
pub fn ratio(&self) -> f32
pub fn new( ctx: &WgpuContext, width: u32, height: u32, oit_layers: usize, ) -> Self
pub fn new_render_textures(&self, ctx: &WgpuContext) -> RenderTextures
Sourcepub fn render_frame(
&mut self,
render_textures: &mut RenderTextures,
clear_color: Color,
frame: &RenderFrame,
)
pub fn render_frame( &mut self, render_textures: &mut RenderTextures, clear_color: Color, frame: &RenderFrame, )
Reconcile and render one evaluated frame.
Sourcepub fn take_last_gpu_scopes(&mut self) -> Option<Vec<GpuTimerQueryResult>>
pub fn take_last_gpu_scopes(&mut self) -> Option<Vec<GpuTimerQueryResult>>
Take the GPU timer scopes recorded for the most recent processed frame (empty unless GPU timers are enabled and the device supports timestamp queries).
Sourcepub fn gpu_timers_supported(&self) -> bool
pub fn gpu_timers_supported(&self) -> bool
Whether the device supports GPU timestamp queries.
Sourcepub fn gpu_timers_enabled(&self) -> bool
pub fn gpu_timers_enabled(&self) -> bool
Whether GPU timer scopes are currently being recorded (see
Renderer::set_gpu_timers_enabled).
Sourcepub fn set_gpu_timers_enabled(&mut self, on: bool)
pub fn set_gpu_timers_enabled(&mut self, on: bool)
Enable/disable GPU timer recording at runtime. While enabled, each frame pays a device poll to read the timers back.