Renderer

Struct Renderer 

pub struct Renderer {
    pub(crate) width: u32,
    pub(crate) height: u32,
    pub(crate) resolution_info: ResolutionInfo,
    pub(crate) pipelines: PipelinesPool,
    pub(crate) packets: RenderPackets,
    pub(crate) render_graph: GlobalRenderGraph,
    pub(crate) merged_buffer: Option<VItemsBuffer>,
    pub(crate) merged_mesh_buffer: Option<MeshItemsBuffer>,
    pub(crate) profiler: GpuProfiler,
}

Fields

width: u32height: u32resolution_info: ResolutionInfopipelines: PipelinesPoolpackets: RenderPacketsrender_graph: GlobalRenderGraphmerged_buffer: Option<VItemsBuffer>

Present when using the merged rendering path (lazily initialized on first use).

merged_mesh_buffer: Option<MeshItemsBuffer>

Present when using the merged mesh rendering path (lazily initialized on first use).

profiler: GpuProfiler
Available on crate feature profiling only.

Implementations

Source

impl Renderer

pub fn width(&self) -> u32

pub fn height(&self) -> u32

pub fn ratio(&self) -> f32

pub(crate) fn build_render_graph() -> GlobalRenderGraph

pub fn new( ctx: &WgpuContext, width: u32, height: u32, oit_layers: usize, ) -> Self

pub fn new_with_graph( ctx: &WgpuContext, width: u32, height: u32, oit_layers: usize, render_graph: GlobalRenderGraph, ) -> Self

pub fn new_render_textures(&self, ctx: &WgpuContext) -> RenderTextures

pub fn render_store_with_pool( &mut self, ctx: &WgpuContext, render_textures: &mut RenderTextures, clear_color: Color, store: &CoreItemStore, pool: &mut RenderPool, )

Render a frame. Pushes viewport + VItem packets via pool, then execs the render graph.